aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/core/kernels/conv_ops_test.cc
diff options
context:
space:
mode:
Diffstat (limited to 'tensorflow/core/kernels/conv_ops_test.cc')
-rw-r--r--tensorflow/core/kernels/conv_ops_test.cc62
1 files changed, 32 insertions, 30 deletions
diff --git a/tensorflow/core/kernels/conv_ops_test.cc b/tensorflow/core/kernels/conv_ops_test.cc
index 4f9a96ce17..c281153795 100644
--- a/tensorflow/core/kernels/conv_ops_test.cc
+++ b/tensorflow/core/kernels/conv_ops_test.cc
@@ -44,41 +44,43 @@ struct ConvParametersPeer {
TEST(ConvParameters, WinogradNonfusedAlgoSize) {
ConvParametersPeer conv_params_small = {{
- 1, // batch
- 32, // in_depths
- {{300, // in_rows
- 300}}, // in_cols
- 128, // out_depths
- {{3, // filter_rows
- 3}}, // filter_cols
- {{1, // dilation_rows
- 1}}, // dilation_cols
- {{1, // stride_rows
- 1}}, // stride_cols
- {{0, // padding_rows
- 0}}, // padding_cols
- DT_FLOAT, // tensor datatype
- 0, // device_id
+ 1, // batch
+ 32, // in_depths
+ {{300, // in_rows
+ 300}}, // in_cols
+ FORMAT_NCHW, // compute_data_format
+ 128, // out_depths
+ {{3, // filter_rows
+ 3}}, // filter_cols
+ {{1, // dilation_rows
+ 1}}, // dilation_cols
+ {{1, // stride_rows
+ 1}}, // stride_cols
+ {{0, // padding_rows
+ 0}}, // padding_cols
+ DT_FLOAT, // tensor datatype
+ 0, // device_id
}};
EXPECT_TRUE(
conv_params_small.ShouldIncludeWinogradNonfusedAlgoPreCudnn7<float>());
ConvParametersPeer conv_params_large = {{
- 1, // batch
- 128, // in_depths
- {{300, // in_rows
- 300}}, // in_cols
- 768, // out_depths
- {{3, // filter_rows
- 3}}, // filter_cols
- {{1, // dilation_rows
- 1}}, // dilation_cols
- {{1, // stride_rows
- 1}}, // stride_cols
- {{0, // padding_rows
- 0}}, // padding_cols
- DT_FLOAT, // tensor datatype
- 0, // device_id
+ 1, // batch
+ 128, // in_depths
+ {{300, // in_rows
+ 300}}, // in_cols
+ FORMAT_NCHW, // compute_data_format
+ 768, // out_depths
+ {{3, // filter_rows
+ 3}}, // filter_cols
+ {{1, // dilation_rows
+ 1}}, // dilation_cols
+ {{1, // stride_rows
+ 1}}, // stride_cols
+ {{0, // padding_rows
+ 0}}, // padding_cols
+ DT_FLOAT, // tensor datatype
+ 0, // device_id
}};
EXPECT_FALSE(
conv_params_large.ShouldIncludeWinogradNonfusedAlgoPreCudnn7<float>());